==> gallery3-3.0.2.tbz: www/gallery3/modules/tag/helpers/tag_block.php <==
<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2011 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
class tag_block_Core {
  static function get_site_list() {
    return array("tag" => t("Popular tags"));
  }

  static function get($block_id, $theme) {
    $block = "";
    switch ($block_id) {
    case "tag":
      $block = new Block();
      $block->css_id = "g-tag";
      $block->title = t("Popular tags");
      $block->content = new View("tag_block.html");
      $block->content->cloud = tag::cloud(module::get_var("tag", "tag_cloud_size", 30));

      if ($theme->item() && $theme->page_subtype() != "tag" && access::can("edit", $theme->item())) {
        $controller = new Tags_Controller();
        $block->content->form = tag::get_add_form($theme->item());
      } else {
        $block->content->form = "";
      }
      break;
    }
    return $block;
  }
}

==> gallery3-3.0_7.tbz: www/gallery3/modules/tag/helpers/tag_block.php <==
<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2010 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
class tag_block_Core {
  static function get_site_list() {
    return array("tag" => t("Popular tags"));
  }

  static function get($block_id, $theme) {
    $block = "";
    switch ($block_id) {
    case "tag":
      $block = new Block();
      $block->css_id = "g-tag";
      $block->title = t("Popular tags");
      $block->content = new View("tag_block.html");
      $block->content->cloud = tag::cloud(30);

      if ($theme->item() && $theme->page_subtype() != "tag" && access::can("edit", $theme->item())) {
        $controller = new Tags_Controller();
        $block->content->form = tag::get_add_form($theme->item());
      } else {
        $block->content->form = "";
      }
      break;
    }
    return $block;
  }
}
